
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Carroll, Slacalek and Sommer: International Evidence on Sticky
% Consumption Growth
%
% This MATLAB program is called by "run_kalman.m" and constructs the maximum likelihood function used to
% estimate the "true" consumption growth of section 3.2.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function l = kalman_likel(thetax, c, status);

% MA(1) measurement error in log levels, MA(2) in growth rates, time aggregation
z = [1 0 0 1 0 0];

% thetax(4)=0;

myoptions_fsolve = optimset('fsolve');
myoptions_fsolve = optimset(myoptions_fsolve, 'Display', 'off');
warning off;
gamma = abs(thetax(1)) ; % value of the habit formation coefficient
x = fsolve(@(x) solveLambdas(x,gamma),[0.4;0], myoptions_fsolve); %obtain coefficients for the time-aggregation MA terms
%disp(x');

tmat = [thetax(1) 0 0 0 x(1) x(2); 0 0 0 0 0 0; 0 -thetax(4) 0 0 0 0; 0 0 1 0 0 0; 0 0 0 0 0 0; 0 0 0 0 1 0];
h=0;
q=[exp(thetax(3)) 0 0 0 exp(thetax(3)) 0; ...
   0 exp(thetax(2)) (thetax(4)-1)*exp(thetax(2)) exp(thetax(2)) 0 0; ...
   0 (thetax(4)-1)*exp(thetax(2)) ((thetax(4)-1)^2)*exp(thetax(2)) (thetax(4)-1)*exp(thetax(2)) 0 0; ...
   0 exp(thetax(2)) (thetax(4)-1)*exp(thetax(2)) exp(thetax(2)) 0 0; ...
   exp(thetax(3)) 0 0 0 exp(thetax(3)) 0; ...
   0 0 0 0 0 0];
a0g0 = zeros(6,1);
p0g0 = reshape( inv(eye(36)-kron(tmat,tmat))*reshape(q,36,1), 6,6 );

[xsmooth, Vsmooth, VVsmooth, loglik] = kalman_filter(c, tmat, z, q, h, a0g0, p0g0);
l=-loglik;
%disp([l thetax]);

if status == 1;
%   capt = length(c);
%  figure; plot(1:capt, c, 1:capt, xsmooth(1,:)); title('Measured and "true" consumption growth');
  
%disp('True cons. growth');
%format long;
%disp([xsmooth(1,:)']);
%format short;

disp('var_ratio');
disp(var(xsmooth(1,:))/var(c));
saveRatio=var(xsmooth(1,:))/var(c);

% disp('R sq.');
% disp( ( thetax(1)^2 * var(xsmooth(1,:)) + (x(1)^2 + x(2)^2) * var(xsmooth(5,:)) ) / var(xsmooth(1,:)) );

save('.\dataNoutput\results_kalman.mat');
end;
